<?php

/**
 * @file plugins/oaiMetadataFormats/dc/index.php
 *
 * Copyright (c) 2014-2021 Simon Fraser University
 * Copyright (c) 2003-2021 John Willinsky
 * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 *
 * @ingroup plugins_oaiMetadataFormats
 *
 * @brief Wrapper for the OAI DC format plugin.
 *
 */

return new \APP\plugins\oaiMetadataFormats\dc\OAIMetadataFormatPlugin_DC();
